# Each change to the spec requires a bump to version/release of both library and perlmod
%global library_version 1.2.10
%global library_release 9%{?dist}
%global perlmod_version 0.01
%global perlmod_release 12%{?dist}

# Set to 1 for a compat-libspf2 package
%global compat 0

# Fedora 10, RHEL 6 onwards support noarch subpackages
%if 0%{?fedora} > 9 || 0%{?rhel} >= 6
%global build_apidocs_noarch 1
%endif

%if %{compat}
Name:		compat-libspf2
%else
Name:		libspf2
%endif
Version:	%{library_version}
Release:	%{library_release}
Summary:	An implementation of the SPF specification
License:	BSD or LGPLv2+
Group:		System Environment/Libraries
URL:		http://www.libspf2.org/
Source0:	http://www.libspf2.org/spf/libspf2-%{version}.tar.gz
Patch0:		libspf2-1.2.10-format.patch
Patch1:		libspf2-1.2.10-libreplace.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	sed
# For API docs
BuildRequires:	doxygen, graphviz
# For perl bindings (Makefile.PL claims Mail::SPF is needed, but it isn't)
BuildRequires:	perl
%if 0%{?fedora} > 6 || 0%{?rhel} > 5
BuildRequires:	perl-devel
%endif
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# For perl test suite
BuildRequires:	perl(String::Escape)
BuildRequires:	perl(Test::Pod)
# POD Coverage is non-existent, causes test suite to fail
BuildConflicts:	perl(Test::Pod::Coverage)
# Perl module fails the standard test suite
BuildConflicts:	perl(Mail::SPF::Test)
%if %{compat}
Provides:	libspf2 = %{version}-%{release}
%endif

%description
libspf2 is an implementation of the SPF (Sender Policy Framework)
specification as found at:
http://www.ietf.org/internet-drafts/draft-mengwong-spf-00.txt
SPF allows email systems to check SPF DNS records and make sure that
an email is authorized by the administrator of the domain name that
it is coming from. This prevents email forgery, commonly used by
spammers, scammers, and email viruses/worms.

A lot of effort has been put into making it secure by design, and a
great deal of effort has been put into the regression tests.

%if ! %{compat}
%package devel
Summary:	Development tools needed to build programs that use libspf2
Group:		Development/Libraries
Version:	%{library_version}
Release:	%{library_release}
Requires:	%{name} = %{version}-%{release}

%description devel
The libspf2-devel package contains the header files and static
libraries necessary for developing programs using the libspf2 (Sender
Policy Framework) library.

If you want to develop programs that will look up and process SPF records,
you should install libspf2-devel.

API documentation is in the separate libspf2-apidocs package.

%package apidocs
Summary:	API documentation for the libspf2 library
Group:		Documentation
Version:	%{library_version}
Release:	%{library_release}
%{?build_apidocs_noarch:BuildArch: noarch}

%description apidocs
The libspf2-apidocs package contains the API documentation for creating
applications that use the libspf2 (Sender Policy Framework) library.

%package -n perl-Mail-SPF_XS
Summary:	An XS implementation of Mail::SPF
Group:		Development/Libraries
License:	GPL+ or Artistic
Version:	%{perlmod_version}
Release:	%{perlmod_release}
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description -n perl-Mail-SPF_XS
This is an interface to the C library libspf2 for the purpose of
testing. While it can be used as an SPF implementation, you can also
use Mail::SPF, which is a little more perlish.

%package progs
Summary:	Programs for making SPF queries using libspf2
Group:		Applications/Internet
Version:	%{library_version}
Release:	%{library_release}
Requires:	%{name} = %{version}-%{release}

Requires(post): /usr/sbin/alternatives
Requires(preun): /usr/sbin/alternatives
Requires(postun): /usr/sbin/alternatives, /usr/bin/readlink

%description progs
Programs for making SPF queries and checking their results using libspf2.
%endif

%prep
%setup -q -n libspf2-%{version}

# SPF_debugf macro should always have at least two parameters
%patch0

# libreplace is not needed on modern Linux
%if 0%{?fedora} > 9 || 0%{?rhel} > 5
rm -rf src/libreplace
%patch1
find . -name Makefile.am -print | xargs touch
find . -name Makefile.in -print | xargs touch
%endif

%build
%configure --enable-perl --disable-dependency-tracking

# Kill bogus RPATHs
sed -i 's|^sys_lib_dlsearch_path_spec="/lib /usr/lib|sys_lib_dlsearch_path_spec="/%{_lib} %{_libdir}|' libtool

make %{?_smp_mflags} CFLAGS="%{optflags} -fno-strict-aliasing"

# Generate API docs
sed -i -e 's/\(SHORT_NAMES[[:space:]]*=[[:space:]]*\)NO/\1YES/' Doxyfile
doxygen

%install
rm -rf %{buildroot}
make \
	DESTDIR=%{buildroot} \
	PERL_INSTALL_ROOT=$(grep DESTDIR perl/Makefile &> /dev/null && echo "" || echo %{buildroot}) \
	INSTALLDIRS=vendor \
	INSTALL="install -p" \
	install

# Clean up after impure perl installation
find %{buildroot} \( -name perllocal.pod -o -name .packlist \) -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} %{buildroot}

# Don't want statically-linked binaries
rm -f %{buildroot}%{_bindir}/spf*_static

# Rename binaries that will be accessed via alternatives
mv -f %{buildroot}%{_bindir}/spfquery	%{buildroot}%{_bindir}/spfquery.libspf2
mv -f %{buildroot}%{_bindir}/spfd	%{buildroot}%{_bindir}/spfd.libspf2

# Remove files not needed for compat package
%if %{compat}
rm -rf %{buildroot}%{_bindir}
rm -rf %{buildroot}%{_includedir}/spf2
rm -rf %{buildroot}%{_libdir}/*.a
rm -rf %{buildroot}%{_libdir}/*.la
rm -rf %{buildroot}%{_libdir}/*.so
rm -rf %{buildroot}%{_mandir}/man3
rm -rf %{buildroot}%{perl_vendorarch}
%endif

%check
LD_PRELOAD=$(pwd)/src/libspf2/.libs/libspf2.so make -C perl test

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%if ! %{compat}
%post progs
/usr/sbin/alternatives --install %{_bindir}/spfquery spf %{_bindir}/spfquery.libspf2 20 \
	--slave %{_bindir}/spfd spf-daemon %{_bindir}/spfd.libspf2
exit 0

%preun progs
if [ $1 = 0 ]; then
	/usr/sbin/alternatives --remove spf %{_bindir}/spfquery.libspf2
fi
exit 0

%postun progs
if [ "$1" -ge "1" ]; then
	spf=`readlink /etc/alternatives/spf`
	if [ "$spf" == "%{_bindir}/spfquery.libspf2" ]; then
		/usr/sbin/alternatives --set spf %{_bindir}/spfquery.libspf2
	fi
fi
exit 0

%triggerpostun -- libspf2-progs <= 1.0.4-3
/usr/sbin/alternatives --auto spf
%endif

%files
%if 0%{?_licensedir:1}
%license LICENSES
%else
%doc LICENSES
%endif
%doc README TODO
%{_libdir}/libspf2.so.*

%if ! %{compat}
%files devel
%{_includedir}/spf2/spf*.h
%{_libdir}/libspf2.so
%exclude %{_libdir}/libspf2.a
%exclude %{_libdir}/libspf2.la

%files apidocs
%doc doxygen/html

%files progs
%{_bindir}/spfd.libspf2
%{_bindir}/spfquery.libspf2
%{_bindir}/spftest
%{_bindir}/spf_example

%files -n perl-Mail-SPF_XS
%{perl_vendorarch}/Mail/
%{perl_vendorarch}/auto/Mail/
%{_mandir}/man3/Mail::SPF_XS.3*
%endif

%changelog
* Sun May 29 2016 Paul Howarth <paul@city-fan.org> - 1.2.10-9
- Flesh out build dependencies
- Simplify find commands using -empty and -delete

* Sat Feb 13 2016 Paul Howarth <paul@city-fan.org> - 1.2.10-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Jun 20 2015 Paul Howarth <paul@city-fan.org> - 1.2.10-7
- Perl 5.22 rebuild

* Fri Apr 10 2015 Paul Howarth <paul@city-fan.org> - 1.2.10-6
- Remove libreplace in %%prep, not needed on modern Linux

* Mon Mar  9 2015 Paul Howarth <paul@city-fan.org> - 1.2.10-1
- Update to 1.2.10
  - Fixes IPv6-related issues
- Drop now-redundant workaround to avoid linking to private __ns_get16
- Add patch to fix SPF_debugf macro usage
- Upstream has dropped the broken test suite so drop support for running it

* Mon Sep  1 2014 Paul Howarth <paul@city-fan.org> - 1.2.9-4
- Modernize spec and drop support for old distributions prior to FC-5:
  - Build API documentation unconditionally
  - Don't use macros for commands
  - Drop %%defattr, redundant since rpm 4.4
  - Use %%license where possible
  - Don't need to remove empty directories from the buildroot
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 1.2.9-3
- Rebuild for perl 5.12.1 in Rawhide
- Build with -fno-strict-aliasing

* Mon May 11 2009 Paul Howarth <paul@city-fan.org> - 1.2.9-2
- Define RPM macros in global scope
- apidocs subpackage no longer requires devel subpackage
- apidocs is noarch from Fedora 10 onwards

* Mon Nov 10 2008 Paul Howarth <paul@city-fan.org> - 1.2.9-1
- New upstream version 1.2.9
- Perl module has changed but its version number hasn't
- docs directory no longer included in release tarball

* Wed Oct 15 2008 Paul Howarth <paul@city-fan.org> - 1.2.8-1
- New upstream version 1.2.8, includes fix for CVE-2008-2469
  (buffer overflows handling DNS responses)
- Drop all patches, all included upstream (or equivalent fixes)
- Fix bogus RPATHs on x86_64
- Enable perl bindings (in perl-Mail-SPF_XS subpackage)
- No upstream Changelog anymore
- Add buildreqs doxygen and graphviz for building API docs, which are large
  and now in an -apidocs subpackage (Fedora 3, RHEL 4 onwards)
- Add buildreq perl(ExtUtils::MakeMaker) for perl bindings
- Add buildreqs perl(Test::Pod) and perl(String::Escape) for perl module test
  suite
- BuildConflict with perl(Mail::SPF::Test) and perl(Test::Pod::Coverage) as
  the associated tests are beyond simple repair

* Thu Jul 31 2008 Paul Howarth <paul@city-fan.org> - 1.2.5-4
- Incorporate patches for res_ninit() setup and malloc() usage from
  Johann Klasek <johann AT klasek DOT at>
  (see http://milter-greylist.wikidot.com/libspf2)
- Clarify license as BSD OR LGPL (v2.1 or later)
- Add dist tag so that we can build distro-specific RPM packages instead of a
  single generic package; the benefit of this is that recent distributions can
  take advantages of improvements in their compilers
- Use regular %%configure macro to pick up distro-specific compiler flags
- Don't package static library (--disable-static configure option is broken)
- Dispense with pointless provide of `spf'

* Mon Feb 12 2007 Paul Howarth <paul@city-fan.org> - 1.2.5-3
- Cosmetic spec file cleanup
- Use patch instead of scripted edit to remove bogus include file reference
- Patch to make 64-bit clean
  (http://permalink.gmane.org/gmane.mail.spam.spf.devel/1212)
- Remove buildroot unconditionally in %%clean and %%install
- Don't include libtool archive in -devel package
- Disable running of test suite by default

* Wed Aug  3 2005 Paul Howarth <paul@city-fan.org> - 1.2.5-2
- Workaround for %%check with rpm-build ≤ 4.1.1
- Remove reference to not-installed spf_dns_internal.h in spf_server.h
- Minimize rpmlint issues

* Thu Feb 24 2005 Paul Howarth <paul@city-fan.org> - 1.2.5-1
- Update to 1.2.5
- Patches removed; now included upstream

* Sun Feb 20 2005 Paul Howarth <paul@city-fan.org> - 1.2.1-1
- Update to 1.2.1
- Remove case-sensitivity patch
- spf_example_2mx no longer included

* Sun Feb 20 2005 Paul Howarth <paul@city-fan.org> - 1.0.4-9
- Enhance detection of Mandrake build system
- Add support for building compat-libspf2 package
- alternatives is a prerequisite for the -progs subpackage only

* Thu Oct 28 2004 Paul Howarth <paul@city-fan.org> - 1.0.4-8
- Downgrade alternatives priority to 20 so that other implementations
  of spfquery will be preferred; there is still a case-sensitivity bug
  in libspf2 and no sign of an imminent fix

* Mon Aug 16 2004 Paul Howarth <paul@city-fan.org> - 1.0.4-7
- Configure fix to find -lresolv on x64_64
- Portability fixes for x64_64

* Sun Aug  1 2004 Paul Howarth <paul@city-fan.org> - 1.0.4-6
- Fix case-sensitivity bug

* Wed Jul 28 2004 Paul Howarth <paul@city-fan.org> - 1.0.4-5
- Revert -pthread option as it didn't improve anything

* Tue Jul 27 2004 Paul Howarth <paul@city-fan.org> - 1.0.4-4
- Use `alternatives' so that the spfquery and spfd programs can co-exist
  with versions from other implementations
- Ensure thread-safe operation by building with -pthread

* Thu Jul 15 2004 Paul Howarth <paul@city-fan.org> - 1.0.4-3
- Install the libtool library in the devel package so that
  dependent libraries are found properly
- Use the libtool supplied with the package rather than the
  system libtool

* Tue Jul 13 2004 Paul Howarth <paul@city-fan.org> - 1.0.4-2
- Cosmetic changes for building on Mandrake Linux
- Require rpm-build ≥ 4.1.1 for building to avoid strange error messages
  from old versions of rpm when they see %%check
- Require glibc-devel and make for building
- Require perl for building with checks enabled
- Improved description text for the packages

* Fri Jul 09 2004 Paul Howarth <paul@city-fan.org> - 1.0.4-1
- Update to 1.0.4
- Added facility to build without running test suite
  (rpmbuild --without checks)

* Sat Jul 03 2004 Paul Howarth <paul@city-fan.org> - 1.0.3-1
- Initial RPM build
